==> hyperscas2-0.0.7.tar.gz: hyperscas2-0.0.7/cas/auth.py <==
import requests

from django.contrib.auth import get_user_model
from django.utils.translation import ugettext as _
from rest_framework import exceptions
from rest_framework.authentication import \
    TokenAuthentication as _TokenAuthentication, BaseAuthentication
from rest_framework.authentication import get_authorization_header

User = get_user_model()


class OAuthAuthentication(BaseAuthentication):
    # 新的登录验证 直接使用此Authentication
    auth_header = 'HTTP_X_AUTH_USER'

    def authenticate(self, request):
        email = request.META.get(self.auth_header, "")
        if not email:
            return None
        return self.authenticate_credentials(email, request)

    def authenticate_credentials(self, email, request=None):
        try:
            user = User.objects.get(email=email)
        except User.DoesNotExist:
            raise exceptions.PermissionDenied(_("用户不存在"))

        return user, None


class OAuth2Authentication(_TokenAuthentication):
    keyword = "bearer"

    def authenticate(self, request):
        auth = get_authorization_header(request).split()

        if not auth or auth[0].lower() != self.keyword.lower().encode():
            return None

        if len(auth) == 1:
            msg = _("Invalid token header. No credentials provided.")
            raise exceptions.AuthenticationFailed(msg)
        if len(auth) > 2:
            msg = _("Invalid token header. Token string should not contain spaces.")
            raise exceptions.AuthenticationFailed(msg)

        try:
            token = auth[1].decode()
        except UnicodeError:
            msg = _(
                "Invalid token header. Token string should not contain invalid characters."
            )
            raise exceptions.AuthenticationFailed(msg)

        return self.authenticate_credentials(token, request)

    def authenticate_credentials(self, key, request=None):
        url = request.domain.auth.oauth2
        params = {"token": key}

        try:
            response = requests.get(url, params=params).json()
        except Exception:
            response = {}
        email = response.get("user_name", "")

        # 若AccessToken校验未通过, 返回401, 转发AS端返回的错误信息
        if not email:
            raise exceptions.NotAuthenticated(response)

        try:
            user = User.objects.get(email=email)
        except User.DoesNotExist:
            raise exceptions.PermissionDenied(_("用户不存在"))

        return user, None

    def authenticate_header(self, request):
        return self.keyword

==> hyperscas-2.0.3.tar.gz: hyperscas-2.0.3/cas/auth.py <==
import requests

from django.contrib.auth import get_user_model
from django.utils.translation import ugettext as _
from rest_framework import exceptions
from rest_framework.authentication import \
    TokenAuthentication as _TokenAuthentication, BaseAuthentication
from rest_framework.authentication import get_authorization_header

User = get_user_model()


class OAuthAuthentication(BaseAuthentication):
    # 新的登录验证 直接使用此Authentication
    auth_header = 'HTTP_X_AUTH_USER'
    def authenticate(self, request):
        email = request.META.get(self.auth_header,"")
        if not email:
            return None
        return self.authenticate_credentials(email, request)

    def authenticate_credentials(self, email, request=None):
        try:
            user = User.objects.get(email=email)
        except User.DoesNotExist:
            raise exceptions.PermissionDenied(_("用户不存在"))

        return user, None

class OAuth2Authentication(_TokenAuthentication):
    keyword = "bearer"

    def authenticate(self, request):
        auth = get_authorization_header(request).split()

        if not auth or auth[0].lower() != self.keyword.lower().encode():
            return None

        if len(auth) == 1:
            msg = _("Invalid token header. No credentials provided.")
            raise exceptions.AuthenticationFailed(msg)
        if len(auth) > 2:
            msg = _("Invalid token header. Token string should not contain spaces.")
            raise exceptions.AuthenticationFailed(msg)

        try:
            token = auth[1].decode()
        except UnicodeError:
            msg = _(
                "Invalid token header. Token string should not contain invalid characters."
            )
            raise exceptions.AuthenticationFailed(msg)

        return self.authenticate_credentials(token, request)

    def authenticate_credentials(self, key, request=None):
        url = request.domain.auth.oauth2
        params = {"token": key}

        try:
            response = requests.get(url, params=params).json()
        except Exception:
            response = {}
        email = response.get("userEmail", "")

        # 若AccessToken校验未通过, 返回401, 转发AS端返回的错误信息
        if not email:
            raise exceptions.NotAuthenticated(response)

        try:
            user = User.objects.get(email=email)
        except User.DoesNotExist:
            raise exceptions.PermissionDenied(_("用户不存在"))

        return user, None

    def authenticate_header(self, request):
        return self.keyword
